@@ -59,12 +59,17 @@
    If not set, then character classes are not supported.  */
 #define RE_CHAR_CLASSES (1L << 9)
 
-#define RE_OPTION_EXTENDED   (1L<<0)
+/* match will be done case insensetively */
 #define RE_OPTION_IGNORECASE (1L<<1)
-#define RE_MAY_IGNORECASE    (1L<<2)
-#define RE_OPTIMIZE_ANCHOR   (1L<<4)
-#define RE_OPTIMIZE_EXACTN   (1L<<5)
-#define RE_OPTIMIZE_NO_BM    (1L<<6)
+/* perl-style extended pattern available */
+#define RE_OPTION_EXTENDED   (RE_OPTION_IGNORECASE<<1)
+/* newline will be included for . and invert charclass matches */
+#define RE_OPTION_POSIX      (RE_OPTION_EXTENDED<<1)
+
+#define RE_MAY_IGNORECASE    (RE_OPTION_POSIX<<1)
+#define RE_OPTIMIZE_ANCHOR   (RE_MAY_IGNORECASE<<1)
+#define RE_OPTIMIZE_EXACTN   (RE_OPTIMIZE_ANCHOR<<1)
+#define RE_OPTIMIZE_NO_BM    (RE_OPTIMIZE_ANCHOR<<1)
 
 /* For multi-byte char support */
 #define MBCTYPE_ASCII 0
