@@ -147,9 +147,17 @@ time_s_at(klass, time)
     VALUE klass, time;
 {
     struct timeval tv;
+    VALUE t;
 
     tv = rb_time_timeval(time);
-    return time_new_internal(klass, tv.tv_sec, tv.tv_usec);
+    t = time_new_internal(klass, tv.tv_sec, tv.tv_usec);
+    if (TYPE(time) == T_DATA) {
+	struct time_object *tobj;
+
+	GetTimeval(t, tobj);
+	tobj->gmt = 1;
+    }
+    return t;
 }
 
 static char *months [12] = {
